@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-11-29'; # DATE
-our $VERSION = '0.71'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.72'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -175,6 +175,8 @@ sub _fmt_opt {
 
     if (($ospec->{orig_opt} // '') =~ /\@/) {
         push @res, "Can be specified multiple times.\n\n";
+    } elsif (($ospec->{orig_opt} // '') =~ /\%/) {
+        push @res, "Each value is a name-value pair, use I<key=value> syntax. Can be specified multiple times.\n\n";
     }
 
     join "", @res;
@@ -893,7 +895,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.71 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-11-29.
+This document describes version 0.72 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-12-10.
 
 =head1 SYNOPSIS
 
@@ -992,7 +994,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
 
 =head1 BUGS
 
